@@ -549,12 +549,21 @@ int main(
           {
           if (strcmp(keyword, ATTR_depend) == 0)
             {
+            int rtn = 0;
             pdepend = malloc(PBS_DEPEND_LEN);
 
             if ((pdepend == NULL) ||
-                 parse_depend_list(valuewd,pdepend,PBS_DEPEND_LEN))
+                 (rtn = parse_depend_list(valuewd,pdepend,PBS_DEPEND_LEN)))
               {
-              fprintf(stderr, "qalter: illegal -W value\n");
+              if (rtn == 2)
+                {
+                fprintf(stderr,"qalter: -W value exceeded max length (%d)\n",
+                  PBS_DEPEND_LEN);
+                }
+              else
+                {
+                fprintf(stderr,"qalter: illegal -W value\n");
+                }
 
               errflg++;
 
