@@ -95,6 +95,51 @@
 #define DBPRT(x) printf x;
 #endif  /* END NDEBUG */
 
+#if SYSLOG
+#include <syslog.h>
+#endif /* SYSLOG */
+
+#if !SYSLOG
+/* define syslog constants that can be used in code regardless of whether we
+ * are using syslog or not! */
+
+#ifndef LOG_EMERG
+#define LOG_EMERG 1
+#endif
+
+#ifndef LOG_ALERT
+#define LOG_ALERT 2
+#endif
+
+#ifndef LOG_CRIT
+#define LOG_CRIT 3
+#endif
+
+#ifndef LOG_ERR
+#define LOG_ERR 4 
+#endif
+
+#ifndef LOG_ERR
+#define LOG_ERR 5 
+#endif
+
+#ifndef LOG_WARNING
+#define LOG_WARNING 6
+#endif
+
+#ifndef LOG_NOTICE
+#define LOG_NOTICE 7
+#endif
+
+#ifndef LOG_INFO
+#define LOG_INFO 8
+#endif
+
+#ifndef LOG_DEBUG
+#define LOG_DEBUG 9
+#endif
+#endif /* SYSLOG */
+
 extern long *log_event_mask;
 
 /* set this to non-zero in calling app if errors go to stderr */
@@ -103,11 +148,13 @@ extern int   chk_file_sec_stderr;
 
 extern void log_close A_((int));
 extern void log_err A_((int, char *, char *));
+extern void log_ext A_((int,char *,char *,int));
 extern void log_event A_((int, int, char *, char *));
 extern int  log_open A_((char *, char *));
 extern void log_record A_((int, int, char *, char *));
 extern void log_roll A_((int));
 extern long log_size A_((void));
+extern int  log_remove_old A_((char *,unsigned long));
 extern char log_buffer[LOG_BUF_SIZE];
 int log_init A_((char *, char *));
 
@@ -141,3 +188,13 @@ extern int  setup_env A_((char *));
 /* Logging Masks */
 
 #define PBSEVENT_MASK  0x01ff
+
+/* definition's for pbs_log.c's log_remove_old() function */
+#define MAX_PATH_LEN    1024  /* maximum possible length of any path */
+#define SECS_PER_DAY     86400
+
+#if !defined(TRUE) || !defined(FALSE)
+#define TRUE 1
+#define FALSE 0
+#endif /* !defined(TRUE) || !defined(FALSE) */
+
