@@ -171,6 +171,7 @@ extern double cputfactor;
 extern  double wallfactor;
 extern  long    system_ncpus;
 extern  int     ignwalltime;
+extern  int     ignvmem;
 
 /*
 ** local functions and data
@@ -704,7 +705,7 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
       {
       reslim.rlim_cur = reslim.rlim_max = mem_limit;
 
-      if (setrlimit(RLIMIT_VMEM, &reslim) < 0)
+      if ((ignvmem == 0) && (setrlimit(RLIMIT_VMEM, &reslim) < 0))
         return (error("RLIMIT_VMEM", PBSE_SYSTEM));
       }
     }
@@ -924,7 +925,7 @@ job   *pjob;
       if (retval != PBSE_NONE)
         continue;
 
-      if ((num = mem_sum(pjob)) > value)
+      if ((ignvmem == 0) && ((num = mem_sum(pjob)) > value))
         {
         sprintf(log_buffer,
                 "vmem %lu exceeded limit %lu",
