@@ -102,7 +102,8 @@
 #include <sys/procfs.h>
 #include <sys/proc.h>
 #include <sys/resource.h>
-
+#include <ctype.h>
+#include <signal.h>
 #include "pbs_error.h"
 #include "portability.h"
 #include "list_link.h"
@@ -136,7 +137,7 @@
 **  loadave  current load average
 */
 
-static char ident[] = "@(#) solaris5/$RCSfile$ $Revision: 2628 $";
+static char ident[] = "@(#) solaris5/$RCSfile$ $Revision: 3390 $";
 
 #ifndef TRUE
 #define FALSE 0
@@ -354,7 +355,7 @@ job   *pjob;
   int   i;
   int   nps = 0;
   prstatus_t  *ps;
-  prpsinfo_t  *pi;
+  prpsinfo_t  *pi = NULL;
 
   cputime = 0;
 
@@ -370,8 +371,8 @@ job   *pjob;
     if (pi->pr_state == SZOMB)
       {
       cputime += tv(pi->pr_time);
-      DBPRT(("%s: ses %d pid %d (zombie) cputime %d\n",
-             id, pi->pr_sid, pi->pr_pid, cputime))
+      DBPRT(("%s: ses %d pid %d (zombie) cputime %ld\n",
+             id, (int)pi->pr_sid, (int)pi->pr_pid, cputime))
       continue;
       }
 
@@ -381,8 +382,8 @@ job   *pjob;
               tv(ps->pr_cutime) + tv(ps->pr_cstime);
 
     cputime += addtime;
-    DBPRT(("%s: ses %d pid %d cputime %d\n",
-           id, pi->pr_sid, ps->pr_pid, cputime))
+    DBPRT(("%s: ses %d pid %d cputime %ld\n",
+           id, (int)pi->pr_sid, (int)ps->pr_pid, cputime))
     }
 
   if (nps == 0)
@@ -401,7 +402,6 @@ static int overcput_proc(pjob, limit)
 job   *pjob;
 unsigned long limit;
   {
-  char  *id = "overcput_proc";
   ulong  memsize;
   ulong  cputime;
   int  i;
@@ -436,10 +436,9 @@ unsigned long limit;
 static unsigned long mem_sum(pjob)
 job   *pjob;
   {
-  char  *id = "mem_sum";
   ulong  memsize;
   int  i;
-  prpsinfo_t *pi;
+  prpsinfo_t *pi = NULL;
 
   memsize = 0;
 
@@ -462,10 +461,9 @@ job   *pjob;
 static unsigned long resi_sum(pjob)
 job   *pjob;
   {
-  char  *id = "resi_sum";
   ulong  resisize;
   int  i;
-  prpsinfo_t *pi;
+  prpsinfo_t *pi = NULL;
 
   resisize = 0;
 
@@ -498,6 +496,9 @@ error(char *string, int value)
   assert(value > PBSE_);   /* minimum PBS error number */
   assert(value <= PBSE_NOSYNCMSTR); /* maximum PBS error number */
   assert(pbs_err_to_txt[i].err_no != 0);
+ 
+  message = ident; /* this is done only to supress a compiler warning which complains
+                      ident is defined but not used */
 
   do
     {
@@ -782,7 +783,7 @@ mom_get_sample(void)
   struct dirent  *dent;
   char   procname[100];
   prstatus_t  *ps;
-  prpsinfo_t  *pi;
+  prpsinfo_t  *pi = NULL;
 
   DBPRT(("%s: entered\n", id))
   rewinddir(pdir);
@@ -936,7 +937,7 @@ job   *pjob;
       if (num > value)
         {
         sprintf(log_buffer,
-                "walltime %d exceeded limit %d",
+                "walltime %ld exceeded limit %ld",
                 num, value);
 
         if (ignwalltime == 0)
@@ -960,7 +961,6 @@ job   *pjob;
 int mom_set_use(pjob)
 job   *pjob;
   {
-  char   *id = "mom_set_use";
   resource  *pres;
   attribute  *at;
   resource_def  *rd;
@@ -1048,9 +1048,8 @@ task *ptask;
 int   sig;
 int         pg;
   {
-  char  *id = "kill_task";
   int  ct = 0;
-  prpsinfo_t *pi;
+  prpsinfo_t *pi = NULL;
   int  i, sesid;
 
   sesid = ptask->ti_qs.ti_sid;
@@ -1149,7 +1148,6 @@ int
 getprocs(void)
   {
   static unsigned int lastproc = 0;
-  static char  id[] = "getprocs";
 
   if (lastproc == reqnum)  /* don't need new proc table */
     return 1;
@@ -1166,7 +1164,7 @@ double
 dsecs(t)
 timestruc_t     *t;
   {
-  DBPRT(("\tsecs: %d\tnsecs: %d\n", t->tv_sec, t->tv_nsec))
+  DBPRT(("\tsecs: %d\tnsecs: %ld\n", (int)t->tv_sec, t->tv_nsec))
   return ((double)t->tv_sec + ((double)t->tv_nsec * 1.0e-9));
   }
 
@@ -1205,7 +1203,7 @@ pid_t jobid;
     cputime += addtime;
 
     DBPRT(("%s: total %.2f pid %d %.2f\n", id, cputime,
-           ps->pr_pid, addtime))
+           (int)ps->pr_pid, addtime))
 
     }
 
@@ -1224,10 +1222,9 @@ char *
 cput_proc(pid)
 pid_t pid;
   {
-  char   *id = "cput_pid";
   double   cputime;
   int   i;
-  prstatus_t  *ps;
+  prstatus_t  *ps = NULL;
 
   if (getprocs() == 0)
     {
@@ -1307,7 +1304,7 @@ pid_t jobid;
   int   memsize;
   int   i;
   int   found = 0;
-  prpsinfo_t  *pi;
+  prpsinfo_t  *pi = NULL;
 
   if (getprocs() == 0)
     {
@@ -1328,13 +1325,13 @@ pid_t jobid;
 
     memsize += pi->pr_size;
 
-    DBPRT(("%s: total %d pid %d %d\n", id, memsize*page_size,
-           pi->pr_pid, pi->pr_size*page_size))
+    DBPRT(("%s: total %ld pid %d %ld\n", id, memsize*page_size,
+           (int)pi->pr_pid, pi->pr_size*page_size))
     }
 
   if (found)
     {
-    sprintf(ret_string, "%ukb", (memsize*page_size) >> 10); /* KB */
+    sprintf(ret_string, "%ldkb", (memsize*page_size) >> 10); /* KB */
     return ret_string;
     }
 
@@ -1347,8 +1344,7 @@ char *
 mem_proc(pid)
 pid_t pid;
   {
-  char   *id = "mem_proc";
-  prpsinfo_t  *pi;
+  prpsinfo_t  *pi = NULL;
   int   i;
 
   if (getprocs() == 0)
@@ -1371,7 +1367,7 @@ pid_t pid;
     return NULL;
     }
 
-  sprintf(ret_string, "%ukb", (pi->pr_size * page_size) >> 10); /* KB */
+  sprintf(ret_string, "%ldkb", (pi->pr_size * page_size) >> 10); /* KB */
 
   return ret_string;
   }
@@ -1419,11 +1415,10 @@ static char *
 resi_job(jobid)
 pid_t jobid;
   {
-  char   *id = "resi_job";
   int   resisize;
   int   i;
   int   found = 0;
-  prpsinfo_t  *pi;
+  prpsinfo_t  *pi = NULL;
 
   if (getprocs() == 0)
     {
@@ -1447,7 +1442,7 @@ pid_t jobid;
 
   if (found)
     {
-    sprintf(ret_string, "%ukb", (resisize*page_size) >> 10); /* KB */
+    sprintf(ret_string, "%ldkb", (resisize*page_size) >> 10); /* KB */
     return ret_string;
     }
 
@@ -1460,8 +1455,7 @@ static char *
 resi_proc(pid)
 pid_t pid;
   {
-  char   *id = "resi_proc";
-  prpsinfo_t  *pi;
+  prpsinfo_t  *pi = NULL;
   int   i;
 
   if (getprocs() == 0)
@@ -1484,7 +1478,7 @@ pid_t pid;
     return NULL;
     }
 
-  sprintf(ret_string, "%ukb", (pi->pr_rssize * page_size) >> 10); /* KB */
+  sprintf(ret_string, "%ldkb", (pi->pr_rssize * page_size) >> 10); /* KB */
 
   return ret_string;
   }
@@ -1533,7 +1527,7 @@ sessions(struct rm_attribute *attrib)
   {
   char   *id = "sessions";
   int   i, j;
-  prpsinfo_t  *pi;
+  prpsinfo_t  *pi = NULL;
   char   *fmt;
   int   njids = 0;
   pid_t   *jids, *hold;
@@ -1574,7 +1568,7 @@ sessions(struct rm_attribute *attrib)
       continue;
 
     DBPRT(("%s[%d]: pid %d sid %d\n",
-           id, njids, pi->pr_pid, jobid))
+           id, (int)njids, (int)pi->pr_pid, (int)jobid))
 
     for (j = 0; j < njids; j++)
       {
@@ -1648,8 +1642,8 @@ pids(struct rm_attribute *attrib)
   {
   char  *id = "pids";
   pid_t  jobid;
-  int  i, j;
-  prpsinfo_t *pi;
+  int  i;
+  prpsinfo_t *pi = NULL;
   char  *fmt;
   int  num_pids;
 
@@ -1699,12 +1693,12 @@ pids(struct rm_attribute *attrib)
     pi = &proc_info[i];
 
     DBPRT(("%s[%d]: pid: %d sid %d\n",
-           id, num_pids, pi->pr_pid, pi->pr_sid))
+           id, num_pids, (int)pi->pr_pid, (int)pi->pr_sid))
 
     if (jobid != pi->pr_sid)
       continue;
 
-    sprintf(fmt, "%d ", pi->pr_pid);
+    sprintf(fmt, "%d ", (int)pi->pr_pid);
 
     fmt += strlen(fmt);
 
@@ -1725,7 +1719,7 @@ nusers(struct rm_attribute *attrib)
   {
   char   *id = "nusers";
   int   i, j;
-  prpsinfo_t  *pi;
+  prpsinfo_t  *pi = NULL;
   int   nuids = 0;
   uid_t   *uids, *hold;
   static  int maxuid = 200;
@@ -1759,7 +1753,7 @@ nusers(struct rm_attribute *attrib)
       continue;
 
     DBPRT(("%s[%d]: pid %d uid %d\n",
-           id, nuids, pi->pr_pid, uid))
+           id, nuids, (int)pi->pr_pid, (int)uid))
 
     for (j = 0; j < nuids; j++)
       {
@@ -1807,7 +1801,7 @@ ncpus(struct rm_attribute *attrib)
     return NULL;
     }
 
-  sprintf(ret_string, "%d", sysconf(_SC_NPROCESSORS_ONLN));
+  sprintf(ret_string, "%ld", sysconf(_SC_NPROCESSORS_ONLN));
 
   system_ncpus = sysconf(_SC_NPROCESSORS_ONLN);
   return ret_string;
@@ -1836,9 +1830,6 @@ char *
 size_fs(char *param)
   {
   char  *id = "size_fs";
-  FILE  *mf;
-
-  struct mntent *mp;
 
   struct statvfs fsbuf;
 
@@ -1887,7 +1878,7 @@ size_file(char *param)
     return NULL;
     }
 
-  sprintf(ret_string, "%ukb", sbuf.st_size >> 10); /* KB */
+  sprintf(ret_string, "%ldkb", sbuf.st_size >> 10); /* KB */
 
   return ret_string;
   }
@@ -2002,7 +1993,7 @@ walltime(struct rm_attribute *attrib)
   int   i;
   int   value, job, found = 0;
   time_t   now, start;
-  prpsinfo_t  *pi;
+  prpsinfo_t  *pi = NULL;
 
   if (attrib == NULL)
     {
@@ -2088,14 +2079,17 @@ get_la(double *rv)
   char *id = "get_la";
   kvm_t *kd;
   long load;
+  char *avenrun = "avenrun";
+  static struct nlist nl[2];
 
-  static struct nlist nl[] =
-    {
-      { "avenrun"
-      },
+  nl[0].n_name = avenrun;
+  nl[0].n_value = 0;
+  nl[0].n_scnum = 0;
+  nl[0].n_type = 0;
+  nl[0].n_sclass = NULL;
+  nl[0].n_numaux = NULL;
 
-    { "" }
-    };
+  nl[1].n_name = NULL;
 
   kd = kvm_open(NULL, NULL, NULL, O_RDONLY, NULL);
 
