@@ -97,7 +97,7 @@
 #include "mom_mach.h"
 #include "mom_func.h"
 
-static char ident[] = "@(#) $RCSfile$ $Revision: 2394 $";
+static char ident[] = "@(#) $RCSfile$ $Revision: 3390 $";
 
 /* Global Variables */
 
@@ -208,8 +208,8 @@ scan_for_terminated(void)
   static char id[] = "scan_for_terminated";
   int  exiteval;
   pid_t  pid;
-  job  *pjob;
-  task  *ptask;
+  job  *pjob = NULL;
+  task  *ptask = NULL;
   int  statloc;
 
   /* update the latest intelligence about the running jobs;         */
@@ -273,7 +273,7 @@ scan_for_terminated(void)
     if (pjob == NULL)
       {
       DBPRT(("%s: pid %d not tracked, exit %d\n",
-             id, pid, exiteval))
+             id, (int)pid, exiteval))
       continue;
       }
 
@@ -292,8 +292,8 @@ scan_for_terminated(void)
       }
 
     DBPRT(("%s: task %d pid %d exit value %d\n", id,
+           ptask->ti_qs.ti_task, (int)pid, exiteval))
 
-           ptask->ti_qs.ti_task, pid, exiteval))
     kill_task(ptask, SIGKILL, 0);
     ptask->ti_qs.ti_exitstat = exiteval;
     ptask->ti_qs.ti_status = TI_STATE_EXITED;
@@ -327,6 +327,9 @@ open_master(
   static char ptcchar2[] = "0123456789abcdef";
   static char pty_name[PTY_SIZE+1]; /* "/dev/[pt]tyXY" */
 
+  pc1 = ident; /* This is here to stop a compiler warning because
+                  ident is defined but not used */
+
   (void)strncpy(pty_name, "/dev/ptyXY", PTY_SIZE);
 
   for (pc1 = ptcchar1; *pc1 != '\0'; ++pc1)
