@@ -169,6 +169,7 @@ void req_rerunjob(
 
   {
   job *pjob;
+  struct work_task	*pwt;
 
   int  Force;
 
@@ -239,6 +240,21 @@ void req_rerunjob(
       {
       svr_setjobstate(pjob, JOB_STATE_HELD, JOB_SUBSTATE_HELD);
       }
+    
+    /* reset some job attributes */
+    
+    pjob->ji_wattr[(int)JOB_ATR_comp_time].at_flags &= ~ATR_VFLAG_SET;
+    pjob->ji_wattr[(int)JOB_ATR_reported].at_flags &= ~ATR_VFLAG_SET;
+
+    /*
+     * delete any work task entries associated with the job
+     * there may be tasks for keep_completed proccessing
+     */
+
+    while ((pwt = (struct work_task *)GET_NEXT(pjob->ji_svrtask)) != NULL) 
+      {
+      delete_task(pwt);
+      }
 
     set_statechar(pjob);
 
@@ -250,7 +266,7 @@ void req_rerunjob(
 
     case - 1:
 
-      /* completed job was requeued - NO-OP */
+      /* completed job was requeued */
 
       break;
 
