@@ -971,6 +971,20 @@ attribute_def svr_attr_def[] =
     	PARENT_TYPE_SERVER
   },
 
+  /* SRV_ATR_JobStartTimeout */
+  {   ATTR_jobstarttimeout,         /* "job_start_timeout" */
+      decode_l,
+      encode_l,
+      set_l,
+      comp_l,
+      free_null,
+      NULL_FUNC,
+      NO_USER_SET,
+      ATR_TYPE_LONG,
+      PARENT_TYPE_SERVER
+  },
+
+
   /* site supplied server attribute definitions if any, see site_svr_attr_*.h  */
 #include "site_svr_attr_def.h"
 
